@@ -11,7 +11,7 @@ class Py2NError(Exception):
 
 
 class NotInitialized(Py2NError):
-    """Raised if device is not initialized."""
+    """Raised if device is not yet initialized."""
 
 
 # Expected errors
@@ -19,8 +19,10 @@ class NotInitialized(Py2NError):
 
 
 class DeviceConnectionError(Py2NError):
-    """Exception indicates device connection errors."""
+    """Raised to indicate connection errors."""
 
+class DeviceUnspportedError(Py2NError):
+    """Raised to indicate unspported or non-2N device."""
 
 class ApiError(Enum):
     NOT_SUPPORTED = 1
@@ -43,6 +45,6 @@ class ApiError(Enum):
 
 @dataclass
 class DeviceApiError(Py2NError):
-    """Raised to indicate invalid or missing authentication error."""
+    """Raised to indicate api error."""
 
     error: ApiError
