@@ -1,13 +1,10 @@
 """Models for 2N library."""
 from __future__ import annotations
-from typing import List
-from enum import Enum
 
 import aiohttp
 
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Optional
 
 
 @dataclass
@@ -51,4 +48,4 @@ class Py2NDeviceData:
     firmware: str
     hardware: str
     uptime: datetime
-    switches: List[Py2NDeviceSwitch]
+    switches: list[Py2NDeviceSwitch]
