@@ -9,6 +9,7 @@ from typing import Any, List
 from .const import (
     CONNECT_ERRORS,
     HTTP_CALL_TIMEOUT,
+    CONTENT_TYPE,
     API_SYSTEM_INFO,
     API_SYSTEM_STATUS,
     API_SYSTEM_RESTART,
@@ -19,7 +20,7 @@ from .const import (
 
 from .model import Py2NConnectionData
 
-from .exceptions import Py2NError, DeviceConnectionError, ApiError, DeviceApiError
+from .exceptions import DeviceConnectionError, DeviceUnspportedError, ApiError, DeviceApiError
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -112,12 +113,18 @@ async def api_request(
         async with aiohttp_session.get(
             url, timeout=HTTP_CALL_TIMEOUT, auth=options.auth
         ) as response:
+            if response.content_type != CONTENT_TYPE:
+                raise DeviceUnspportedError("invalid content type")
+                
             result: dict[str, Any] = await response.json()
     except CONNECT_ERRORS as err:
         error = DeviceConnectionError(err)
         _LOGGER.debug("host %s: connect error: %r", options.host, error)
         raise error from err
 
+    if "success" not in result:
+        raise DeviceUnspportedError("response malformed")
+
     if not result["success"]:
         code = result["error"]["code"]
         error = ApiError(code)
